<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>Klicke auf ein beliebiges Bild, um zum Lesezeichen zu gehen</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>Neueste Seite</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation>Standardwerte wiederherstellen</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>Um ein Kürzel zu ändern, klicke doppelt auf die Tastenkombination und füge die neuen Tasten ein.</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation>Kürzel-Einstellungen</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>Genutzte Kürzel</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>Das Kürzel &quot;%1&quot; ist bereits für eine andere Funktion in Verwendung</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation>Format wird nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>7z nicht gefunden</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation>Unbekannter Fehler beim Öffnen des Files</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>CRC Error auf Seite (%1): Einige Seiten werden nicht korrekt dargestellt</translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>Gehe zu...</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>Seiten gesamt :</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>Seite :</translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>Seite :</translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="31"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="34"/>
        <source>System info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="28"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation>Änderungsprotokoll-Fenster</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation>L&amp;öschen</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation>Level</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation>&amp;Automatisches Scrollen</translation>
    </message>
</context>
<context>
    <name>MainWindowViewer</name>
    <message>
        <source>File</source>
        <translation type="vanished">Datei</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Hilfe</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Speichern</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="vanished">&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="vanished">&amp;Nächstes</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Öffnen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schliessen</translation>
    </message>
    <message>
        <source>Open Comic</source>
        <translation type="vanished">Comic öffnen</translation>
    </message>
    <message>
        <source>Go To</source>
        <translation type="vanished">Gehe zu</translation>
    </message>
    <message>
        <source>Open image folder</source>
        <translation type="vanished">Bilder-Ordner öffnen</translation>
    </message>
    <message>
        <source>Set bookmark</source>
        <translation type="vanished">Lesezeichen setzen</translation>
    </message>
    <message>
        <source>page_%1.jpg</source>
        <translation type="vanished">Seite_%1.jpg</translation>
    </message>
    <message>
        <source>Switch to double page mode</source>
        <translation type="vanished">Zum Doppelseiten-Modus wechseln</translation>
    </message>
    <message>
        <source>Save current page</source>
        <translation type="vanished">Aktuelle Seite speichern</translation>
    </message>
    <message>
        <source>Double page mode</source>
        <translation type="vanished">Doppelseiten-Modus</translation>
    </message>
    <message>
        <source>Switch Magnifying glass</source>
        <translation type="vanished">Vergrößerungsglas wechseln</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="vanished">Ordner öffnen</translation>
    </message>
    <message>
        <source>Fit Height</source>
        <translation type="vanished">Höhe anpassen</translation>
    </message>
    <message>
        <source>Comic files</source>
        <translation type="vanished">Comic-Dateien</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="vanished">Nicht jetzt</translation>
    </message>
    <message>
        <source>Go to previous page</source>
        <translation type="vanished">Zur vorherigen Seite gehen</translation>
    </message>
    <message>
        <source>Open a comic</source>
        <translation type="vanished">Comic öffnen</translation>
    </message>
    <message>
        <source>Image files (*.jpg)</source>
        <translation type="vanished">Bildateien (*.jpg)</translation>
    </message>
    <message>
        <source>Next Comic</source>
        <translation type="vanished">Nächster Comic</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation type="vanished">Breite anpassen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="vanished">Optionen</translation>
    </message>
    <message>
        <source>Show Info</source>
        <translation type="vanished">Info anzeigen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ordner öffnen</translation>
    </message>
    <message>
        <source>Go to page ...</source>
        <translation type="vanished">Gehe zu Seite ...</translation>
    </message>
    <message>
        <source>Fit image to width</source>
        <translation type="vanished">Bildbreite anpassen</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="vanished">&amp;Vorherige</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation type="vanished">Zur nächsten Seite gehen</translation>
    </message>
    <message>
        <source>Show keyboard shortcuts</source>
        <translation type="vanished">Tastenkürzel anzeigen</translation>
    </message>
    <message>
        <source>There is a new version available</source>
        <translation type="vanished">Neue Version verfügbar</translation>
    </message>
    <message>
        <source>Open next comic</source>
        <translation type="vanished">Nächsten Comic öffnen</translation>
    </message>
    <message>
        <source>Remind me in 14 days</source>
        <translation type="vanished">In 14 Tagen erneut erinnern</translation>
    </message>
    <message>
        <source>Show bookmarks</source>
        <translation type="vanished">Lesezeichen anzeigen</translation>
    </message>
    <message>
        <source>Open previous comic</source>
        <translation type="vanished">Vorherigen Comic öffnen</translation>
    </message>
    <message>
        <source>Rotate image to the left</source>
        <translation type="vanished">Bild nach links drehen</translation>
    </message>
    <message>
        <source>Fit image to height</source>
        <translation type="vanished">Bild an Höhe anpassen</translation>
    </message>
    <message>
        <source>Show the bookmarks of the current comic</source>
        <translation type="vanished">Lesezeichen für diesen Comic anzeigen</translation>
    </message>
    <message>
        <source>Show Dictionary</source>
        <translation type="vanished">Wörterbuch anzeigen</translation>
    </message>
    <message>
        <source>YACReader options</source>
        <translation type="vanished">YACReader Optionen</translation>
    </message>
    <message>
        <source>Help, About YACReader</source>
        <translation type="vanished">Hilfe, über YACReader</translation>
    </message>
    <message>
        <source>Show go to flow</source>
        <translation type="vanished">&quot;Go to Flow&quot; anzeigen</translation>
    </message>
    <message>
        <source>Previous Comic</source>
        <translation type="vanished">Voheriger Comic</translation>
    </message>
    <message>
        <source>Show full size</source>
        <translation type="vanished">Vollansicht anzeigen</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation type="vanished">Vergößerungsglas</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Allgemein</translation>
    </message>
    <message>
        <source>Set a bookmark on the current page</source>
        <translation type="vanished">Lesezeichen auf dieser Seite setzen</translation>
    </message>
    <message>
        <source>Do you want to download the new version?</source>
        <translation type="vanished">Möchten Sie die neue Version herunterladen?</translation>
    </message>
    <message>
        <source>Rotate image to the right</source>
        <translation type="vanished">Bild nach rechts drehen</translation>
    </message>
    <message>
        <source>Always on top</source>
        <translation type="vanished">Immer Oberste Ansicht</translation>
    </message>
    <message>
        <source>New instance</source>
        <translation type="vanished">Neuer Fall</translation>
    </message>
    <message>
        <source>Open latest comic</source>
        <translation type="vanished">Neuesten Comic öffnen</translation>
    </message>
    <message>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="vanished">Öffne den neuesten Comic deiner letzten Sitzung</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="vanished">Löschen</translation>
    </message>
    <message>
        <source>Clear open recent list</source>
        <translation type="vanished">Lösche Liste zuletzt geöffneter Elemente</translation>
    </message>
    <message>
        <source>Fit to page</source>
        <translation type="vanished">An Seite anpassen</translation>
    </message>
    <message>
        <source>Reset zoom</source>
        <translation type="vanished">Zoom zurücksetzen</translation>
    </message>
    <message>
        <source>Show zoom slider</source>
        <translation type="vanished">Zoomleiste anzeigen</translation>
    </message>
    <message>
        <source>Zoom+</source>
        <translation type="vanished">Zoom+</translation>
    </message>
    <message>
        <source>Zoom-</source>
        <translation type="vanished">Zoom-</translation>
    </message>
    <message>
        <source>Double page manga mode</source>
        <translation type="vanished">Doppelseiten-Manga-Modus</translation>
    </message>
    <message>
        <source>Reverse reading order in double page mode</source>
        <translation type="vanished">Umgekehrte Lesereihenfolge im Doppelseiten-Modus</translation>
    </message>
    <message>
        <source>Edit shortcuts</source>
        <translation type="vanished">Kürzel ändern</translation>
    </message>
    <message>
        <source>Open recent</source>
        <translation type="vanished">Kürzlich geöffnet</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">Ändern</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Anzeigen</translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="vanished">Los</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="vanished">Fenster</translation>
    </message>
    <message>
        <source>Comics</source>
        <translation type="vanished">Comics</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode</source>
        <translation type="vanished">Vollbild-Modus umschalten</translation>
    </message>
    <message>
        <source>Hide/show toolbar</source>
        <translation type="vanished">Symbolleiste anzeigen/verstecken</translation>
    </message>
    <message>
        <source>Size up magnifying glass</source>
        <translation type="vanished">Vergrößerungsglas vergrößern</translation>
    </message>
    <message>
        <source>Size down magnifying glass</source>
        <translation type="vanished">Vergrößerungsglas verkleinern</translation>
    </message>
    <message>
        <source>Zoom in magnifying glass</source>
        <translation type="vanished">Vergrößerungsglas reinzoomen</translation>
    </message>
    <message>
        <source>Zoom out magnifying glass</source>
        <translation type="vanished">Vergrößerungsglas rauszoomen</translation>
    </message>
    <message>
        <source>Magnifiying glass</source>
        <translation type="vanished">Vergrößerungsglas</translation>
    </message>
    <message>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="vanished">Zwischen Anpassung an Seite und Höhe wechseln</translation>
    </message>
    <message>
        <source>Page adjustement</source>
        <translation type="vanished">Seitenanpassung</translation>
    </message>
    <message>
        <source>Autoscroll down</source>
        <translation type="vanished">Automatisches Runterscrollen</translation>
    </message>
    <message>
        <source>Autoscroll up</source>
        <translation type="vanished">Automatisches Raufscrollen</translation>
    </message>
    <message>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="vanished">Automatisches Vorwärtsscrollen, horizontal zuerst</translation>
    </message>
    <message>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="vanished">Automatisches Zurückscrollen, horizontal zuerst</translation>
    </message>
    <message>
        <source>Autoscroll forward, vertical first</source>
        <translation type="vanished">Automatisches Vorwärtsscrollen, vertikal zuerst</translation>
    </message>
    <message>
        <source>Autoscroll backward, vertical first</source>
        <translation type="vanished">Automatisches Zurückscrollen, vertikal zuerst</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation type="vanished">Nach unten</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation type="vanished">Nach oben</translation>
    </message>
    <message>
        <source>Move left</source>
        <translation type="vanished">Nach links</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation type="vanished">Nach rechts</translation>
    </message>
    <message>
        <source>Go to the first page</source>
        <translation type="vanished">Zur ersten Seite gehen</translation>
    </message>
    <message>
        <source>Go to the last page</source>
        <translation type="vanished">Zur letzten Seite gehen</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lesend</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="166"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="170"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>Meine Comics-Pfad</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="214"/>
        <source>Image adjustment</source>
        <translation>Bildanpassung</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="49"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>&quot;Go to flow&quot; Größe</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="70"/>
        <source>Choose</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="175"/>
        <source>Image options</source>
        <translation>Bilderoptionen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="165"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="229"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="236"/>
        <source>Comics directory</source>
        <translation>Comics-Verzeichnis</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="67"/>
        <source>Background color</source>
        <translation>Hintergrundfarbe</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="213"/>
        <source>Page Flow</source>
        <translation>Page Flow</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="212"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="164"/>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="220"/>
        <source>Restart is needed</source>
        <translation>Neustart erforderlich</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="120"/>
        <source>Quick Navigation Mode</source>
        <translation>Schnellnavigations-Modus</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="41"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>Show time in current page information label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="77"/>
        <source>Scroll behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="80"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="81"/>
        <source>Do not turn page using scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="82"/>
        <source>Use single scroll step to turn page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="90"/>
        <source>Mouse mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="93"/>
        <source>Only Back/Forward buttons can turn pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="94"/>
        <source>Use the Left/Right buttons to turn pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="95"/>
        <source>Click left or right half of the screen to turn pages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="121"/>
        <source>Disable mouse over activation</source>
        <translation>Aktivierung durch Maus deaktivieren</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="179"/>
        <source>Fit options</source>
        <translation>Anpassungsoptionen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="181"/>
        <source>Enlarge images to fit width/height</source>
        <translation>Bilder vergrößern, um sie Breite/Höhe anzupassen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Double Page options</source>
        <translation>Doppelseiten-Einstellungen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="194"/>
        <source>Show covers as single page</source>
        <translation>Cover als eine Seite darstellen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation>7z-Verzeichnis nicht gefunden</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>7z -erzeichnis kann von ./utils nicht geladen werden</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation>Verfolgen</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation>Fehlersuche</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation>Fatal</translation>
    </message>
    <message>
        <location filename="../common/yacreader_global_gui.cpp" line="112"/>
        <source>Select custom cover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/yacreader_global_gui.cpp" line="112"/>
        <source>Images (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation>NAchricht</translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation>&amp;Weiter</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation>Protokoll speichern</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation>Protokoll-Datei (*.log)</translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Schliessen</translation>
    </message>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">YACReader Tastaturkürzel</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">Tastaturkürzel</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="1001"/>
        <source>Page not available!</source>
        <translation>Seite nicht verfügbar!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="979"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>&apos;O&apos; drücken, um Comic zu öffnen.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="252"/>
        <source>Error opening comic</source>
        <translation>Fehler beim Öffnen des Comics</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1164"/>
        <source>Cover!</source>
        <translation>Titelseite!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="258"/>
        <source>CRC Error</source>
        <translation>CRC Fehler</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>Comic not found</source>
        <translation>Comic nicht gefunden</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>Not found</source>
        <translation>Nicht gefunden</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1178"/>
        <source>Last page!</source>
        <translation>Letzte Seite!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="991"/>
        <source>Loading...please wait!</source>
        <translation>Ladevorgang... Bitte warten!</translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="187"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="189"/>
        <source>Open a comic</source>
        <translation type="unfinished">Comic öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="195"/>
        <source>New instance</source>
        <translation type="unfinished">Neuer Fall</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="214"/>
        <source>Open Folder</source>
        <translation type="unfinished">Ordner öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="216"/>
        <source>Open image folder</source>
        <translation type="unfinished">Bilder-Ordner öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="221"/>
        <source>Open latest comic</source>
        <translation type="unfinished">Neuesten Comic öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="222"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="unfinished">Öffne den neuesten Comic deiner letzten Sitzung</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Clear</source>
        <translation type="unfinished">Löschen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="235"/>
        <source>Clear open recent list</source>
        <translation type="unfinished">Lösche Liste zuletzt geöffneter Elemente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="238"/>
        <source>Save</source>
        <translation type="unfinished">Speichern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="240"/>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>Save current page</source>
        <translation type="unfinished">Aktuelle Seite speichern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="245"/>
        <source>Previous Comic</source>
        <translation type="unfinished">Voheriger Comic</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="247"/>
        <location filename="main_window_viewer.cpp" line="1680"/>
        <location filename="main_window_viewer.cpp" line="1684"/>
        <source>Open previous comic</source>
        <translation type="unfinished">Vorherigen Comic öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="252"/>
        <source>Next Comic</source>
        <translation type="unfinished">Nächster Comic</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="254"/>
        <location filename="main_window_viewer.cpp" line="1679"/>
        <location filename="main_window_viewer.cpp" line="1685"/>
        <source>Open next comic</source>
        <translation type="unfinished">Nächsten Comic öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="259"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Vorherige</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="262"/>
        <location filename="main_window_viewer.cpp" line="1682"/>
        <location filename="main_window_viewer.cpp" line="1686"/>
        <source>Go to previous page</source>
        <translation type="unfinished">Zur vorherigen Seite gehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="267"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Nächstes</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="270"/>
        <location filename="main_window_viewer.cpp" line="1681"/>
        <location filename="main_window_viewer.cpp" line="1687"/>
        <source>Go to next page</source>
        <translation type="unfinished">Zur nächsten Seite gehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="275"/>
        <source>Fit Height</source>
        <translation type="unfinished">Höhe anpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="278"/>
        <source>Fit image to height</source>
        <translation type="unfinished">Bild an Höhe anpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="285"/>
        <source>Fit Width</source>
        <translation type="unfinished">Breite anpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="288"/>
        <source>Fit image to width</source>
        <translation type="unfinished">Bildbreite anpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="295"/>
        <source>Show full size</source>
        <translation type="unfinished">Vollansicht anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="303"/>
        <source>Fit to page</source>
        <translation type="unfinished">An Seite anpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="334"/>
        <source>Reset zoom</source>
        <translation type="unfinished">Zoom zurücksetzen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="339"/>
        <source>Show zoom slider</source>
        <translation type="unfinished">Zoomleiste anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="342"/>
        <source>Zoom+</source>
        <translation type="unfinished">Zoom+</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="347"/>
        <source>Zoom-</source>
        <translation type="unfinished">Zoom-</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="352"/>
        <source>Rotate image to the left</source>
        <translation type="unfinished">Bild nach links drehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="358"/>
        <source>Rotate image to the right</source>
        <translation type="unfinished">Bild nach rechts drehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="364"/>
        <source>Double page mode</source>
        <translation type="unfinished">Doppelseiten-Modus</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="365"/>
        <source>Switch to double page mode</source>
        <translation type="unfinished">Zum Doppelseiten-Modus wechseln</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="374"/>
        <source>Double page manga mode</source>
        <translation type="unfinished">Doppelseiten-Manga-Modus</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="375"/>
        <source>Reverse reading order in double page mode</source>
        <translation type="unfinished">Umgekehrte Lesereihenfolge im Doppelseiten-Modus</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="384"/>
        <source>Go To</source>
        <translation type="unfinished">Gehe zu</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="386"/>
        <source>Go to page ...</source>
        <translation type="unfinished">Gehe zu Seite ...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="391"/>
        <source>Options</source>
        <translation type="unfinished">Optionen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="392"/>
        <source>YACReader options</source>
        <translation type="unfinished">YACReader Optionen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="399"/>
        <location filename="main_window_viewer.cpp" line="696"/>
        <source>Help</source>
        <translation type="unfinished">Hilfe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="400"/>
        <source>Help, About YACReader</source>
        <translation type="unfinished">Hilfe, über YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="406"/>
        <source>Magnifying glass</source>
        <translation type="unfinished">Vergößerungsglas</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="407"/>
        <source>Switch Magnifying glass</source>
        <translation type="unfinished">Vergrößerungsglas wechseln</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="414"/>
        <source>Set bookmark</source>
        <translation type="unfinished">Lesezeichen setzen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="415"/>
        <source>Set a bookmark on the current page</source>
        <translation type="unfinished">Lesezeichen auf dieser Seite setzen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="424"/>
        <source>Show bookmarks</source>
        <translation type="unfinished">Lesezeichen anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="425"/>
        <source>Show the bookmarks of the current comic</source>
        <translation type="unfinished">Lesezeichen für diesen Comic anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="431"/>
        <source>Show keyboard shortcuts</source>
        <translation type="unfinished">Tastenkürzel anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="437"/>
        <source>Show Info</source>
        <translation type="unfinished">Info anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="443"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="449"/>
        <source>Show Dictionary</source>
        <translation type="unfinished">Wörterbuch anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="456"/>
        <source>Show go to flow</source>
        <translation type="unfinished">&quot;Go to Flow&quot; anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="462"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="485"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Datei</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="500"/>
        <location filename="main_window_viewer.cpp" line="651"/>
        <source>Open recent</source>
        <translation type="unfinished">Kürzlich geöffnet</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="640"/>
        <source>File</source>
        <translation type="unfinished">Datei</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="661"/>
        <source>Edit</source>
        <translation type="unfinished">Ändern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="665"/>
        <source>View</source>
        <translation type="unfinished">Anzeigen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="681"/>
        <source>Go</source>
        <translation type="unfinished">Los</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Window</source>
        <translation type="unfinished">Fenster</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="806"/>
        <location filename="main_window_viewer.cpp" line="808"/>
        <location filename="main_window_viewer.cpp" line="810"/>
        <source>Open Comic</source>
        <translation type="unfinished">Comic öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="806"/>
        <location filename="main_window_viewer.cpp" line="808"/>
        <location filename="main_window_viewer.cpp" line="810"/>
        <source>Comic files</source>
        <translation type="unfinished">Comic-Dateien</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="901"/>
        <source>Open folder</source>
        <translation type="unfinished">Ordner öffnen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>page_%1.jpg</source>
        <translation type="unfinished">Seite_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="957"/>
        <source>Image files (*.jpg)</source>
        <translation type="unfinished">Bildateien (*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1164"/>
        <source>Comics</source>
        <translation type="unfinished">Comics</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1174"/>
        <source>Toggle fullscreen mode</source>
        <translation type="unfinished">Vollbild-Modus umschalten</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1177"/>
        <source>Hide/show toolbar</source>
        <translation type="unfinished">Symbolleiste anzeigen/verstecken</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1180"/>
        <source>General</source>
        <translation type="unfinished">Allgemein</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1199"/>
        <source>Size up magnifying glass</source>
        <translation type="unfinished">Vergrößerungsglas vergrößern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1202"/>
        <source>Size down magnifying glass</source>
        <translation type="unfinished">Vergrößerungsglas verkleinern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1205"/>
        <source>Zoom in magnifying glass</source>
        <translation type="unfinished">Vergrößerungsglas reinzoomen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1208"/>
        <source>Zoom out magnifying glass</source>
        <translation type="unfinished">Vergrößerungsglas rauszoomen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1211"/>
        <source>Reset magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Magnifiying glass</source>
        <translation type="unfinished">Vergrößerungsglas</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="unfinished">Zwischen Anpassung an Seite und Höhe wechseln</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Page adjustement</source>
        <translation type="unfinished">Seitenanpassung</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Autoscroll down</source>
        <translation type="unfinished">Automatisches Runterscrollen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Autoscroll up</source>
        <translation type="unfinished">Automatisches Raufscrollen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="unfinished">Automatisches Vorwärtsscrollen, horizontal zuerst</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1256"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="unfinished">Automatisches Zurückscrollen, horizontal zuerst</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1260"/>
        <source>Autoscroll forward, vertical first</source>
        <translation type="unfinished">Automatisches Vorwärtsscrollen, vertikal zuerst</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1264"/>
        <source>Autoscroll backward, vertical first</source>
        <translation type="unfinished">Automatisches Zurückscrollen, vertikal zuerst</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1268"/>
        <source>Move down</source>
        <translation type="unfinished">Nach unten</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1271"/>
        <source>Move up</source>
        <translation type="unfinished">Nach oben</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1274"/>
        <source>Move left</source>
        <translation type="unfinished">Nach links</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1277"/>
        <source>Move right</source>
        <translation type="unfinished">Nach rechts</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1280"/>
        <source>Go to the first page</source>
        <translation type="unfinished">Zur ersten Seite gehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1283"/>
        <source>Go to the last page</source>
        <translation type="unfinished">Zur letzten Seite gehen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1286"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1288"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1306"/>
        <source>Reading</source>
        <translation type="unfinished">Lesend</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1355"/>
        <source>There is a new version available</source>
        <translation type="unfinished">Neue Version verfügbar</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1356"/>
        <source>Do you want to download the new version?</source>
        <translation type="unfinished">Möchten Sie die neue Version herunterladen?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1359"/>
        <source>Remind me in 14 days</source>
        <translation type="unfinished">In 14 Tagen erneut erinnern</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1360"/>
        <source>Not now</source>
        <translation type="unfinished">Nicht jetzt</translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="116"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Ursprungszustand wiederherstellen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>Anklicken, um zu überschreiben</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Urpsrungszustand wiederherstellen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>Anklicken, um zu überschreiben</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Tielseiten Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Titelseiten Anzeigeoptionen:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Streifen-Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Überlappende Streifen-Ansicht</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>Licht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>Zeige erweiterte Einstellungen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>Zufalls-Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>Titelbild Ansichtswinkel</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>Streifen-Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Z-Anpassung</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Y-Anpassung</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>Mittiger Abstand</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>Voreinstellungen:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>Überlappende Streifen-Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>Moderne Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>Anzeige-Winkel</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>Maximaler Winkel</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>Benutzerdefiniert:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>Klassische Ansicht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>Titelbild-Abstand</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>Hohe Leistung</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>Leistung:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>Benutze VSync (verbessert die Bildqualität im Vollanzeigemodus, schlechtere Leistung)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>Sichtbarkeit</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>Niedrige Leistung</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Nutze Hardwarebeschleunigung (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation>Kürzel bearbeiten</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation>Service nicht verfügbar</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation>Übersetzung</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation>YACReader Übersetzer</translation>
    </message>
</context>
</TS>
